# Selected Python Packages
Curated List by Nikolai von Krusenstiern

## ARES Project
### Text File Parsing
* [Parsing (wiki)](https://en.wikipedia.org/wiki/Parsing)
* [parsimonious](https://pypi.org/project/parsimonious/)
  * [parsimonious (video)](https://www.youtube.com/watch?v=tCUdeLIj4hE)
  * [parsing-text-with-python](https://www.vipinahow-to-parse-complex-text-files-using-pythonjayakumar.com/parsing-text-with-python/)
  * [how-to-parse-complex-text-files-using-python](https://stackoverflow.com/questions/47982949/how-to-parse-complex-text-files-using-python/47984221#47984221)
  * [parsing-in-python](https://tomassetti.me/parsing-in-python/)

### Output Format
* [protobuf](https://pypi.org/project/protobuf/)

### Hadoop Cluster (just read)
* [hadoop-with-python](https://www.oreilly.com/content/hadoop-with-python/)


# Standard Lib
It is a good idea to at least quick read through the [The Python Standard Library](https://docs.python.org/3/library/)

## Typing
* [typing](https://docs.python.org/3/library/typing.html)
  * [type-annotation-types](https://docs.python.org/3/library/stdtypes.html#type-annotation-types-generic-alias-union)

## Standard Types
* [Standard Types](https://docs.python.org/3/library/stdtypes.html)
  * [string](https://docs.python.org/3/library/stdtypes.html#string-methods)
    * [text-sequence-type](https://docs.python.org/3/library/stdtypes.html#text-sequence-type-str)
  * [sequence-types](https://docs.python.org/3/library/stdtypes.html#sequence-types-list-tuple-range)
  * [set-types](https://docs.python.org/3/library/stdtypes.html#set-types-set-frozenset)
  * [mapping-types](https://docs.python.org/3/library/stdtypes.html#mapping-types-dict)
  * [context-manager-types](https://docs.python.org/3/library/stdtypes.html#context-manager-types)
    * [Building A Custom Context Manager In Python: A Closer Look by ArjanCodes (Tutorial)](https://www.youtube.com/watch?v=14z_Tf3p2Mw)

## Logging
* [logging](https://docs.python.org/3/howto/logging.html)

## CLI Parser
* [argparse](https://docs.python.org/3/library/urllib.htmlhttps://docs.python.org/3/library/argparse.html)

## Regular expressions
* [re](https://docs.python.org/3/library/re.html)

## Date / Time
* [datetime](https://docs.python.org/3/library/datetime.html)
* [time](https://docs.python.org/3/library/time.html)

## Context Manager
* [contextlib](https://docs.python.org/3/library/contextlib.html)
* [json](https://docs.python.org/3/library/json.html)

## DB
* [sqlite3](https://docs.python.org/3/library/sqlite3.html)

## Caching
* [lru_cache](https://docs.python.org/3/library/functools.html#functools.lru_cache)
* [cache](https://docs.python.org/3/library/functools.html#functools.cache)

## Web
* [requests](https://docs.python-requests.org/en/latest/)
* [urllib](https://docs.python.org/3/library/urllib.html)
* [webbrowser](https://docs.python.org/3/library/webbrowser.html)

## Printing
* [pprint](https://docs.python.org/3/library/pprint.html)

## Functional Programming
* [functools](https://docs.python.org/3/library/functools.html)

## Data Structures
* [collections](https://docs.python.org/3/library/collections.html)
* [enum](https://docs.python.org/3/library/enum.html)
* [queue](https://docs.python.org/3/library/queue.html)
* [itertools](https://docs.python.org/3/library/itertools.html)


# Other

## Config Management
* [pydantic](https://pydantic-docs.helpmanual.io/)
* [JSON_minify](https://pypi.org/project/JSON_minify/)
* [confuse](https://confuse.readthedocs.io/en/latest/)
  * [PyYAML](https://pypi.org/project/PyYAML/)

## Web
* [requests-cache](https://pypi.org/project/requests-cache/)
* [BeautifulSoup](https://beautiful-soup-4.readthedocs.io/en/latest/)

## Machine Learning
* [pandas](https://pandas.pydata.org/)
* [numpy](https://numpy.org/)

## Date
* [dateparser](https://dateparser.readthedocs.io/en/latest/)
* [readabledelta](https://pypi.org/project/readabledelta/) human-friendly printable version of timedelta

## Printing
* [tabulate](https://pypi.org/project/tabulate/)
* [colorama](https://pypi.org/project/colorama/)

## Visualisation
* [matplotlib](https://matplotlib.org/)
* [seaborn](https://seaborn.pydata.org/)
* [diagrams](https://github.com/mingrammer/diagrams)


# Used Standard Lib
## OS & Files
* [sys](https://docs.python.org/3/library/sys.html)
* [subprocess](https://docs.python.org/3/library/subprocess.html)
* [socket](https://docs.python.org/3/library/socket.html)
* [os](https://docs.python.org/3/library/os.html)
* [resource](https://docs.python.org/3/library/resource.html)
* [glob](https://docs.python.org/3/library/glob.html)
* [shutil](https://docs.python.org/3/library/shutil.html)
* [pathlib](https://docs.python.org/3/library/pathlib.html)
* [difflib](https://docs.python.org/3/library/difflib.html)
* [zipfile](https://docs.python.org/3/library/zipfile.html)

## Math
* [math](https://docs.python.org/3/library/math.html)
* [cmath](https://docs.python.org/3/library/cmath.html)
* [random](https://docs.python.org/3/library/random.html)
* [fractions](https://docs.python.org/3/library/fractions.html)
* [hashlib](https://docs.python.org/3/library/hashlib.html)

## Web & Async
* [asyncio](https://docs.python.org/3/library/asyncio.html)
* [signal](https://docs.python.org/3/library/signal.html)
* [threading](https://docs.python.org/3/library/threading.html)

## Inspect
* [struct](https://docs.python.org/3/library/struct.html)
* [inspect](https://docs.python.org/3/library/inspect.html)
* [platform](https://docs.python.org/3/library/platform.html)

## Build
* [distutils](https://docs.python.org/3/library/distutils.html)


# Good to know
## Inspect
* [lib-programname](https://pypi.org/project/lib-programname/)

## Mail
* [imap-tools](https://pypi.org/project/imap-tools/)

## SQL & DB
* [edgedb](https://pypi.org/project/edgedb/)
* [pymongo](https://pypi.org/project/pymongo/)
* [PyMySQL](https://pypi.org/project/PyMySQL/)

## Astro & Science
* [skyfield](https://rhodesmill.org/skyfield/)
* [astroquery](https://astroquery.readthedocs.io/en/latest/)
* [scipy](https://scipy.org/)
* [geopy](https://pypi.org/project/geopy/)

## High Performance
* [High Performance Python by Micha Gorelick, Ian Ozsvald (book)](https://www.oreilly.com/library/view/high-performance-python/9781449361747/)
* [High Performance Python by Gus Cavanaugh (talk)](https://www.youtube.com/watch?v=ewaY9CcjLt0)
